@@ -19,7 +19,7 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
 
     vLayout = new QVBoxLayout;
 
-    QFont font;
+
     font.setPointSize(22);
 
     label = new QLabel("");
@@ -82,6 +82,8 @@ void ExerciseWindow::sendClosed()
 
 void ExerciseWindow::loadExercise(QList<QString> name)
 {
+    font.setPointSize(22);
+    label->setFont(font);
     qDebug () << "ExerciseWindow::loadExercise 1";
     int i = 0;
     QList <QString> list = xml->getHistoryByExercise(name.first());
@@ -181,6 +183,8 @@ void ExerciseWindow::openED()
 
 void ExerciseWindow::setCurrentExercise(QString name)
 {
+    font.setPointSize(22);
+    label->setFont(font);
     qDebug () << "ExerciseWindow::setCurrentExercise 1";
     int i = 0;
     QList <QString> list;
@@ -302,9 +306,11 @@ void ExerciseWindow::updateTime()
     qDebug () << "updateTime 1";
     //count down wait
     strMin.setNum(min); strSec.setNum(sec); strSet.setNum(set);
-    QString str = strMin + ":" + strSec + " rest left (" + strSet + "set)";
+    QString str = strMin + ":" + strSec + "\n(" + strSet + "set left)";
     btnShake->setEnabled(false);
     label->setText(str);
+    font.setPointSize(28);
+    label->setFont(font);
     qDebug () << "updateTime 2";
     if(sec <= 0)
     {
@@ -314,6 +320,8 @@ void ExerciseWindow::updateTime()
         {
             //wait is over
 
+            font.setPointSize(22);
+            label->setFont(font);
             if(weight[currentSet] != "")
                 label->setText("Exercise: " + currentExercise +  "\nShake when set is done." +
                                "\nLast time on this set: " + weight[currentSet] + "x"  +
@@ -413,8 +421,12 @@ void ExerciseWindow::shaked()
 
     set--;
 
+    font.setPointSize(22);
+    label->setFont(font);
+
     if(set == 0)
     {
+
         qDebug () << "shaked 2";
         timer->stop();
         if(soundActive == true)
@@ -475,6 +487,9 @@ void ExerciseWindow::shaked()
     label->setText(str);
     btnShake->setEnabled(false);
 
+    font.setPointSize(28);
+    label->setFont(font);
+
     qDebug () << "shaked 14";
     reply = interface->call(MCE_TKLOCK_MODE_CHANGE_REQ, "locked");
 
