@@ -42,6 +42,12 @@ void HistoryInfoWindow::load(QString name, QString group)
         else if(list.first() != "0")
             lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " km on " +
                                 list.takeFirst() + " - " + list.takeFirst());
+        else if(list.first() == "0")
+        {
+            list.removeFirst();
+            list.removeFirst();
+            list.removeFirst();
+        }
 
         j++;
     }
