@@ -53,6 +53,35 @@ void NewProgramWindow::load()
     model->sort(0);
 }
 
+void NewProgramWindow::load(QString name, QList <QString> exercises)
+{
+    QList <QString> list;
+    list = xml->openAll();
+
+    if(list.isEmpty())
+    {
+        model->appendRow(new QStandardItem ("No exercises"));
+        lstExercises->setSelectionMode(QListView::NoSelection);
+        return;
+    }
+
+    while(!list.isEmpty())
+    {
+        model->appendRow(new QStandardItem(list.takeFirst()));
+    }
+    model->sort(0);
+
+    txtName->setText(name);
+    txtName->setEnabled(false);
+
+    while(!exercises.isEmpty())
+    {
+        QModelIndex index = model->index(list.takeFirst().toInt(),0);
+        lstExercises->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Select);
+    }
+
+}
+
 void NewProgramWindow::saveExercise()
 {
     QModelIndexList list;
